@@ -4,6 +4,7 @@
 ## Follow a similar idea as  nlsModel() {in "stats"} which returns
 ##  a list of functions sharing a common {non-small!} environment
 
+##                                              vvvvvvvvvvvvvvvvvvvvvvvvvvvvv
 ## NOTA BENE:  Experiments etc are currently in ../misc/experi-psi-rho-funs.R
 ## ---------   (FIXME: move those to ../tests/psi-rho-etc.R and the vignette
 ## ../vignettes//psi_functions.Rnw  (and see ../inst/xtraR/plot-psiFun.R)
@@ -314,10 +315,10 @@ huberPsi <- psiFunc(rho =
                   psi  = function(x, k) pmin.int(k, pmax.int(-k, x)),
                   wgt  = function(x, k) pmin.int(1, k/abs(x)),
                   Dpsi = function(x, k) abs(x) <= k,
-                  Erho = function(k) {iP <- pnorm(k, lower=FALSE)
+                  Erho = function(k) {iP <- pnorm(k, lower.tail=FALSE)
                                       1/2 - iP + k*(dnorm(k) - k*iP)},
                   Epsi2= function(k) ifelse(k < 10,
-                  1 - 2*(k*dnorm(k) + (1-k*k)*pnorm(k, lower=FALSE)), 1),
+                  1 - 2*(k*dnorm(k) + (1-k*k)*pnorm(k, lower.tail=FALSE)), 1),
                   EDpsi= function(k) 2*pnorm(k) - 1,
                   name = "Huber",
                   ## the tuning pars and default:
@@ -451,6 +452,6 @@ tukeyPsi <- c() ##########
 ###
 ## one "challenge" is the  a(b)  needed in  chi(x; a,b) = [x^2 -1 -a]_b^b
 ## for  V-optimal  M-Estimates of scale
-## --> but that's solved (!) in ./scale-chi-opt.R
-##                              ~~~~~~~~~~~~~~~~~
+## --> but that's solved (!) in ~/R/MM/STATISTICS/robust/scale-chi-opt.R & .../scale-chi-opt-Est.R
+##                              ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^       ^^^^^^^^^^^^^^^^^^^
 ## Then, I'd also want the optimal chi for s
