@@ -2,9 +2,12 @@
 
  Authors: Adopted from rowQuantiles.c by R. Gentleman.
 
- Copyright Henrik Bengtsson, 2007;  Martin Maechler, 2014;  History --> EOF
+ Copyright Henrik Bengtsson, 2007;  Martin Maechler, 2014-2021;  History --> EOF
  **************************************************************************/
-#include <Rdefines.h>
+#include <Rinternals.h>
+// was #include <Rdefines.h>
+
+#include "robustbase.h"
 
 //  Public methods:
 
@@ -38,11 +41,11 @@ SEXP R_rowMedians(SEXP x, SEXP naRm, SEXP hasNA, SEXP byRow, SEXP keepNms) {
 
   // Argument checking and "C type coercion":
   if (!isMatrix(x))
-    error("Argument 'x' must be a matrix.");
+    error(_("Argument 'x' must be a matrix."));
 
   int narm = asLogical(naRm); // error if it ain't
   if (narm != TRUE && narm != FALSE)
-    error("Argument 'naRm' must be either TRUE or FALSE.");
+    error(_("Argument 'naRm' must be either TRUE or FALSE."));
 
   int hasna = asLogical(hasNA); // error if it ain't
   if (hasna == NA_INTEGER)
@@ -67,7 +70,7 @@ SEXP R_rowMedians(SEXP x, SEXP naRm, SEXP hasNA, SEXP byRow, SEXP keepNms) {
   } else if (isInteger(x)) {
       ans = PROTECT(rowMedians_Integer(x, nrow, ncol, narm, hasna, byrow));
   } else {
-      error("Argument 'x' must be numeric (integer or double).");
+      error(_("Argument 'x' must be numeric (integer or double)."));
   }
   if(keepnms) {
       SEXP xDnms = getAttrib(x, R_DimNamesSymbol);
