@@ -41,23 +41,25 @@ double _WHIMED_(double *a, _WGT_TYPE_ *w, int n,
   n: number of observations
   w: array of (int/double) weights of the observations.
 */
-
-    int n2, i, kcand;
+    int i;
     /* sum of weights: `int' do overflow when  n ~>= 1e5 */
     _WGT_SUM_TYPE_ wleft, wmid, wright, w_tot, wrest;
-
     double trial;
 
-    w_tot = 0;
+    w_tot = wrest = 0;
     for (i = 0; i < n; ++i)
 	w_tot += w[i];
-    wrest = 0;
+
+#ifdef DEBUG_whimed
+    REprintf("wgt_himed(a[], w[], n)  -- on entry: n=%d, w_tot=%g\n", n, (double)w_tot);
+#endif
+    if(n == 0) return NA_REAL;
 
 /* REPEAT : */
     do {
+	int n2 = n/2;/* =^= n/2 +1 with 0-indexing */
 	for (i = 0; i < n; ++i)
 	    a_srt[i] = a[i];
-	n2 = n/2;/* =^= n/2 +1 with 0-indexing */
 	rPsort(a_srt, n, n2);
 	trial = a_srt[n2];
 
@@ -74,7 +76,12 @@ double _WHIMED_(double *a, _WGT_TYPE_ *w, int n,
 	 * wmid	 = sum_{i; a[i] == trial}  w[i] at least one 'i' since trial is one a[]!
 	 * wright= sum_{i; a[i]	 > trial}  w[i]
 	 */
-	kcand = 0;
+#ifdef DEBUG_whimed
+	REprintf(" trial=%-g; w(left|mid|right) = (%g,%g,%g); ", trial,
+		 (double)wleft, (double)wmid, (double)wright);
+#endif
+
+	int kcand = 0;
 	if (2 * (wrest + wleft) > w_tot) {
 	    for (i = 0; i < n; ++i) {
 		if (a[i] < trial) {
@@ -91,12 +98,21 @@ double _WHIMED_(double *a, _WGT_TYPE_ *w, int n,
 		}
 	    }
 	    wrest += wleft + wmid;
+#ifdef DEBUG_whimed
+	    REprintf(" new wrest = %g; ", (double)wrest);
+#endif
 	}
 	else {
+#ifdef DEBUG_whimed
+	    REprintf(" -> found! return trial\n");
+#endif
 	    return trial;
 	    /*==========*/
 	}
 	n = kcand;
+#ifdef DEBUG_whimed
+	REprintf("  ... and try again with  n:= kcand=%d\n", n);
+#endif
 	for (i = 0; i < n; ++i) {
 	    a[i] = a_cand[i];
 	    w[i] = w_cand[i];
