@@ -3,6 +3,8 @@
 
 require(robustbase)
 
+source(system.file("xtraR/styleData.R", package = "robustbase"))# -> smallD, mkMx()
+
 stopifnot(exprs = {
     all.equal(scaleTau2(c(-4:4, 10000), consistency=FALSE),
              (scaleTau2(c(-4:4, 1e300), consistency=FALSE) -> sT), # <- gave NaN, now fine !
@@ -10,21 +12,6 @@ stopifnot(exprs = {
     all.equal(3.41103800034854, sT, tol = 1e-14) # seen 6.5e-16
 })
 
-mkMx <- function(M, ngood = 10, left = floor(ngood/3)) {
-    stopifnot(is.numeric(ngood), ngood >= 3,
-              is.numeric(M), length(M) == 1L, M >= 1000,
-              is.numeric(left), 0 <= left, left <= ngood)
-    right <- ngood-left
-    res <- list(
-        c(rep(-M, left), seq_len(ngood - 1L), rep(M, right)) # < 50% "good"
-      , c(rep(-M, left), seq_len(ngood     ), rep(M, right)) # half  "good"
-      , c(rep(-M, left), seq_len(ngood + 1L), rep(M, right)) # > 50% "good"
-    )
-    nM <- gsub("[-+]", "", formatC(M, digits=2, width=1))
-    names(res) <- paste0("M", nM,"_n", c("m1", "eq", "p1"))
-    res
-}
-
 exL <- c(
     list( xNA  = c(NA, 1:6)
        , xMe9 = c(-4:4, 1e9)
@@ -32,15 +19,10 @@ exL <- c(
        , xI   = c(-4:4, Inf)
        , IxI  = c(-Inf, -4:4, Inf)
        , IxI2 = c(-Inf, -4:4, Inf,Inf))
-  ##
-, mkMx(M = .Machine$double.xmax)
-, mkMx(M = 1e6)
-, mkMx(M = 1e9)
-, mkMx(M = 1e12)
-, mkMx(M = 1e14)
-, mkMx(M = 1e16)
-, mkMx(M = 1e20)
-, mkMx(M = 1e40)
+    ,
+    mkMx(c(1e6, 1e9,
+           1e12, 1e14, 1e16,
+           1e20, 1e40, .Machine$double.xmax, Inf))
 )
 
 madL <- vapply(exL, mad, pi)
@@ -64,12 +46,12 @@ stopifnot(exprs = {
     mad(exL$xI, constant = 1) == 2.5
 })
 
-## FIXME: should not give NaN :
-scaleTau2(xI)
-
-## FIXME: even give  Error in ..... : NA/NaN/Inf in foreign function call (arg 1)
-try( Sn(xI) )
-try( Qn(xI) )
+stopifnot(exprs = {
+    all.equal(3.5471741782, scaleTau2(xI)) # gave NaN
+    ## These even gave  Error in ..... : NA/NaN/Inf in foreign function call (arg 1)
+    all.equal(3.5778,       Sn(xI))
+    all.equal(3.1961829592, Qn(xI))
+})
 
 ## From  example(mc)  {by MM} :
 
@@ -77,16 +59,21 @@ try( Qn(xI) )
 dX10 <- function(X) c(1:5,7,10,15,25, X) # generate skewed size-10 with 'X'
 (Xs <- c(10,20,30, 60, 10^(2:10), 1000^(4:19), 1e6^c(10:20,10*(3:5)), Inf))
 
-(mc10x <- vapply(Xs, function(x) mc(dX10(x)), 1))
+mc10x <- vapply(Xs, function(x) mc(dX10(x)), 1)
+## now fixed:
+stopifnot(all.equal(c(4,6, rep(7,42))/12, mc10x))
 plot(Xs, mc10x, type="b", main = "mc( c(1:5,7,10,15,25, X) )", xlab="X", log="x")
 
-##--- FIXME: the above must change!
-
 ## so, Inf does work, indeed for mc()
-dX10(Inf)
-set.seed(2020-12-04)
+mcOld <- function(x, ..., doScale=TRUE) mc(x, doScale=doScale, c.huberize=Inf, ...)
+(x10I <- dX10(Inf))
+set.seed(2020-12-04)# rlnorm(.)
+summary(xlN <- rlnorm(100))
+xII <- c(-Inf, xlN, Inf)
 stopifnot(exprs = {
-    is.finite(mc(dX10(Inf))) # 0.5 currently
-    mc(c(-Inf, rlnorm(100), Inf)) == 0
+    all.equal(0.5,  print(mcOld(x10I)))
+    all.equal(7/12, print(mc   (x10I, doScale=TRUE ))) # was 0.5 before huberization
+    all.equal(7/12, print(mc   (x10I, doScale=FALSE)))
+    mcOld(xII) == 0
+    all.equal(0.3646680319, mc(xII))
 })
-
